@@ -13,7 +13,7 @@ GeomInteractiveLinerange <- ggproto(
   default_aes = add_default_interactive_aes(GeomLinerange),
   parameters = interactive_geom_parameters,
   draw_key = interactive_geom_draw_key,
-  draw_panel = function(data, panel_params, coord, flipped_aes = FALSE, .ipar = IPAR_NAMES) {
+  draw_panel = function(data, panel_params, coord, lineend = "butt", flipped_aes = FALSE, na.rm = FALSE, .ipar = IPAR_NAMES) {
     data <- flip_data(data, flipped_aes)
     data <- transform(data,
                       xend = x,
@@ -22,7 +22,8 @@ GeomInteractiveLinerange <- ggproto(
     data <- flip_data(data, flipped_aes)
     ggname(
       "geom_linerange_interactive",
-      GeomInteractiveSegment$draw_panel(data, panel_params, coord, .ipar = .ipar)
+      GeomInteractiveSegment$draw_panel(data, panel_params, coord, lineend = lineend, na.rm = na.rm,
+                                        .ipar = .ipar)
     )
   }
 )
